@@ -2,7 +2,7 @@ use v5.14;
 
 package Datify;
 # ABSTRACT: Simple stringification of data.
-our $VERSION = '0.18.347'; # VERSION
+our $VERSION = '0.18.348'; # VERSION
 
 
 use overload ();
@@ -661,40 +661,32 @@ sub keyify {
 
 
 
-sub keysort($$);
+sub _cmp_;
 BEGIN {
     if ( $^V >= v5.16.0 ) {
-        *keysort = Sub::Util::set_subname(
-            keysort => sub($$) {
-                my $na = Scalar::Util::looks_like_number( $_[0] )
-                    && defined( $_[0] <=> 0 );
-                my $nb = Scalar::Util::looks_like_number( $_[1] )
-                    && defined( $_[1] <=> 0 );
-                if ( $na && $nb ) { return $_[0] <=> $_[1] }
-                elsif ($na) { return -1 }
-                elsif ($nb) { return +1 }
-                else {
-                    return CORE::fc( $_[0] ) cmp CORE::fc( $_[1] )
-                        ||           $_[0]   cmp           $_[1];
-                }
-            }
-        );
+        eval <<'END_CMP';
+sub _cmp_ {
+    return CORE::fc( $_[0] ) cmp CORE::fc( $_[1] )
+        ||           $_[0]   cmp           $_[1];
+}
+END_CMP
     } else {
-        *keysort = Sub::Util::set_subname(
-            keysort => sub($$) {
-                my $na = Scalar::Util::looks_like_number( $_[0] )
-                    && defined( $_[0] <=> 0 );
-                my $nb = Scalar::Util::looks_like_number( $_[1] )
-                    && defined( $_[1] <=> 0 );
-                if ( $na && $nb ) { return $_[0] <=> $_[1] }
-                elsif ($na) { return -1 }
-                elsif ($nb) { return +1 }
-                else        { return $_[0] cmp $_[1] }
-            }
-        );
+        eval <<'END_CMP';
+sub _cmp_ { $_[0] cmp $_[1] }
+END_CMP
     }
 }
 
+sub keysort($$) {
+    my ( $a, $b ) = @_;
+    my $numa = Datify->is_numeric($a);
+    my $numb = Datify->is_numeric($b);
+       $numa && $numb ? $a <=> $b
+    :  $numa          ? -1
+    :           $numb ?        +1
+    :  _cmp_( $a, $b )
+    ;
+}
 
 
 sub hashkeys {
@@ -1583,7 +1575,7 @@ C<HASH> or C<ARRAY>, should it pass through or not?
 
 How to sort the keys in a hash.  This has a performance hit,
 but it makes the output much more readable.  See the description of
-L</keysort>.
+L</keysort($$)>.
 
 =item I<keywords>         => B<[qw(undef)]>
 
@@ -1893,7 +1885,7 @@ For normal values, remove the leading C<main::>.
 
 =head1 FUNCTIONS
 
-=head2 C<keysort>
+=head2 C<keysort($$)>
 
 Not a method, but a sorting routine that sorts numbers (using C<< <=> >>)
 before strings (using C<cmp>).
@@ -1923,7 +1915,7 @@ L<Data::Dumper>
 
 =head1 VERSION
 
-version 0.18.347
+version 0.18.348
 
 =head1 AUTHOR
 
